@@ -23,9 +23,12 @@ from pymongo import MongoClient
 
 logger = logging.getLogger(__name__)
 
-class Api(object):
 
-    def __init__(self, project_name, mongodb_uri='mongodb://localhost', connect_timeout_ms=5000):
+class Api(object):
+    DEFAULT_TIMEOUT = 5000
+    DEFAULT_MONGO_URI = 'mongodb://localhost'
+
+    def __init__(self, project_name, mongodb_uri=DEFAULT_MONGO_URI, connect_timeout_ms=DEFAULT_TIMEOUT):
         """Initialization of class api.
 
         See http://docs.mongodb.org/manual/reference/connection-string/ for
@@ -46,22 +49,30 @@ class Api(object):
             date = datetime.datetime.utcnow()
             host = urlparse.urlparse(url)
 
-            data = {'content': content,
-                    'date': date,
-                    'host': host.hostname,
-                    'method': method,
-                    'project_name': self.project_name,
-                    'response_time': time.time() - start,
-                    'status_code': status_code,
-                    'url': url,
+            time_bucket = [
+                date.strftime('%Y-%m-%d %H:%M-minute'),
+                date.strftime('%Y-%m-%d %H-hour'),
+                date.strftime('%Y-%m-%d-day'),
+            ]
+
+            data = {
+                'content': content,
+                'date': date,
+                'host': host.hostname,
+                'method': method,
+                'response_time': time.time() - start,
+                'status_code': status_code,
+                'url': url,
+                'time_bucket': time_bucket,
             }
 
             try:
-                datas = self.db.datas
+                # Optimization in order to improve speed: losing resolution in time
+                collection = self.db["{}_raw".format(self.project_name)]
                 # the w parameter is making the insertion to db asynchronous
-                datas.insert(data, w=0)
+                collection.insert(data, w=0)
             except:
-                logger.exception('Error writing to MongoDB.')
+                logger.exception('Error writing to MongoDB')
 
     def request(self, method, url, **kwargs):
         """calls a method of request library while storing info about api call into mongo db"""
